pub struct NewTask {
pub project_id: i64,
pub title: String,
pub body: String,
pub priority: Priority,
pub state: TaskState,
pub agent: Option<String>,
pub human: bool,
}Expand description
Initial state for a task created by a human. proposed is quick capture;
parked/ready mean the creator has already triaged their own task.
Fields
project_id: i64title: Stringbody: Stringpriority: Prioritystate: TaskStateagent: Option<String>human: boolTrait Implementations